SUPPORTED_MODELS = {
    # Anthropic Claude
    "Claude Haiku 3": {"id": "claude-3-haiku-20240307", "input": 0.25, "output": 1.25},
    "Claude Haiku 4.5": {
        "id": "claude-haiku-4-5-20251001",
        "input": 1.0,
        "output": 5.0,
    },
    "Claude Sonnet 3.7": {
        "id": "claude-3-7-sonnet-20250219",
        "input": 3.0,
        "output": 15.0,
    },
    "Claude Sonnet 4.5": {
        "id": "claude-sonnet-4-5-20250929",
        "input": 3.0,
        "output": 15.0,
    },
    "Claude Opus 4,5": {
        "id": "claude-opus-4-5-20251101",
        "input": 5.0,
        "output": 25.0,
    },  # very good stuff
    # OpenAI TODO: check OpenAI models
    # "gpt-3.5-turbo": {"input": 0.50, "output": 1.50},
    "gpt-4": {"input": 30.0, "output": 60.0},
    # "gpt-4-turbo": {"input": 10.0, "output": 30.0},
}
